#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_THIRDROOTEPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_THIRDROOTEPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/thirdrooteps.hpp>

#endif
